// ELEMENT.locale(ELEMENT.lang.en)
// Vue app

var app = new Vue({
  el: '#app',
  data: function() {
    return {
      hideInstruction: true,
      stepInstruction: 0,
      search: '',
      showAll: false,
      menus: [],
      commands: [],
      toolbars: [],
      history: [],
      hasMissing: false,
      selectedMenu: {
        name: 'Menu'
      },
      selectedTray: {
        name: ''
      },
      svgImageCommands : [],
      settingsDialogVisible : false,
      windowHeight: 500,
      windowWidth: 500,
      loading: true
    }
  },
  watch: {
    search(newValue, oldValue) {
      sketchup.search(newValue)
    },
    focus(newValue, oldValue) {
      // console.log("focus" + newValue)
      sketchup.mouseFocusChanged(newValue)
    },
  }, 
  methods: {
    nextInstruction() {
      if (this.stepInstruction++ > 2) this.stepInstruction = 0;
    },
    skipInstruction(){
      this.hideInstruction = true
      sketchup.hideInstruction(true);
      // window.localStorage.setItem('curic_piemenu_hide_instruction', true);
    },
    showAllItems(){
      sketchup.showAllItems(this.showAll, this.search);
    },
    componentData() {
      return {
        on: {
          select: this.selectTray,
        },
        props: {
          defaultActive: this.activeTrayIndex(),
        }
      }
    },
    changeTrayPosition(e, a, b) {
      var tray = e.item.__vue__.$attrs.name;
      sketchup.changeTrayPosition(tray, e.oldIndex, e.newIndex, this.selectedMenu.basename);
      tray = this.selectedMenu.trays[e.newIndex];
      this.selectedTray = tray;
      // console.log('changeTrayPosition', tray, e.oldIndex, e.newIndex)
    },
    activeMenuIndex(){
      return this.selectedMenu ? this.selectedMenu.name : '0';
    },
    activeTrayIndex(){
      return this.selectedTray ? this.selectedTray.name : this.selectedMenu.trays[0].name;
    },
    trayIndex(tray){
      // console.log('trayIndex', tray.name, this.selectedMenu.trays.indexOf(tray))
      return this.selectedMenu.trays.indexOf(tray) + ''
    },
    selectMenu(key, keyPath) {
      // console.log(key, keyPath);

      this.selectedMenu = this.menus.find(m => {return m.name == key });
      this.selectedTray = this.selectedMenu.trays[0]
      sketchup.changeMenu(this.selectedMenu);
    },   
    selectTray(key, keyPath) {
      // console.log("selectTray", key, keyPath);

      this.selectedTray = this.selectedMenu.trays.find(t=>{return t.name == key });
      // console.log(key, keyPath, this.selectedTray);
      sketchup.changeTray(this.selectedTray, this.selectedMenu.basename);
    },   
    
     handleOpen(key, keyPath) {
      // console.log(key, keyPath);
    },
    handleClose(key, keyPath) {
      // console.log(key, keyPath);
    },
    newMenu(){
      this.$prompt('输入名称', '新菜单', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
      }).then(({ value }) => {
        if (this.validMenuName(value)){
          sketchup.new(value);
          this.$message({
            type: 'success',
            message: `现在您可以为 "${value}" 菜单 in Tools/Curic/Pie Menu/Show ${value}设置快捷方式 (如果未找到，则重启 SketchUp)`
          });
        }
      }).catch(() => {
        // 
      });
    },
    
    removeMenu(){
      if (!this.selectedMenu) { return };

      if (this.selectedMenu.name == 'Menu'){
        this.$alert('无法删除默认菜单', '错误', {
          confirmButtonText: 'OK',
        });
        return;
      }

      var m = `正在删除 ${this.selectedMenu.name}. 继续吗?`
      this.$confirm(m, '警告', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        // console.log(this.selectedMenu.basename)
        sketchup.removeMenu(this.selectedMenu.basename)
      })
    },
    exportMenu(){
      sketchup.export(this.selectedMenu)
    },
    loadMenu(){
      sketchup.load()
    },
    menuSettings(){
      this.settingsDialogVisible = true
    },
    renameMenu(menu){
      if (menu.name == 'Menu'){
        this.$alert('不能重命名默认菜单', '错误', {
          confirmButtonText: '确认',
        });
        return;
      }

      // Rename
      this.$prompt('建筑G提示：填入想要的名称', '重命名', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        inputValue: menu.name
      }).then(({ value }) => {
        if (value != menu.name && this.validMenuName(value)){
          sketchup.renameMenu(value, menu.name);
          menu.name = value;
          menu.basename = menu.name + '.json';
          if(menu.shortcut){
            this.$message({
              type: 'info',
              message: '更改菜单名称需要重新启动SketchUp才能编辑快捷方式！'
            });
          }
        }
      }).catch(() => {
          // 
      });
    },
    newTray(){
      this.$prompt('输入名称', '新托盘', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
      }).then(({ value }) => {
        if (this.validTrayName(value)){
          // this.$message({
          //   type: 'success',
          //   message: 'Menu name is:' + value
          // });

          sketchup.newTray(value, this.selectedMenu.basename);
        }
      }).catch(() => {
        // 
      });
    },

    removeTray(){
      if (!this.selectedTray) { return };

      var m = `正在删除 ${this.selectedTray.name}. 断续吗?`
      this.$confirm(m, '警告', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        this.$delete(this.selectedMenu.trays, this.selectedMenu.trays.indexOf(this.selectedTray))
        sketchup.removeTray(this.selectedTray.name)
        if(this.selectedMenu.trays.length == 0){
          this.selectedMenu.trays.push({ name: 'Default' })
        }
      })
    },
    editTray(tray){
      // Rename
      this.$prompt('输入新名称', '重命名', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        inputValue: tray.name
      }).then(({ value }) => {
        if (value != tray.name && this.validTrayName(value)){
          sketchup.renameTray(value, tray.name, this.selectedMenu.basename);
          tray.name = value
        }
      }).catch(() => {
        // this.$message({
        //   type: 'info',
        //   message: 'Input canceled'
        // });       
      });
    },

    validMenuName(name){
      if (!name || name.replace(/\s/g, '') == ''){ 
        this.$message({
          type: 'error',
          message: '无效名称'
        });

        return false;
      };
      
      exist_menu = this.menus.find(m => { return m.name == name });

      if (exist_menu){
        this.$message({
          type: 'error',
          message: '重复名称'
        });

        return false;
      }

      return true;
    },
    validTrayName(name){
      if (!name || name.replace(/\s/g, '') == ''){ 
        this.$message({
          type: 'error',
          message: '无效名称'
        });

        return false;
      };
      
      exist= this.selectedMenu.trays.find(m => { return m.name == name });

      if (exist){
        this.$message({
          type: 'error',
          message: '重复名称'
        });

        return false;
      }

      return true;
    },

    showMissings(){
      sketchup.showMissings();
    },

    addCommand(cmd){
      sketchup.addCommand(cmd);
    },

    addToolbar(toolbar){
      // console.log(toolbar)
      sketchup.addToolbar(toolbar);
    },
    addCircleLayout(){
      sketchup.AddLayout('circle');
    },
    addCircleReactangleLayout(){
      sketchup.AddLayout('rectangle');
    },
    mouseOver(){
      this.focus = true
    },
    mouseLeave(){
      this.focus = false
    },
    layoutUI() {
      // Set height for font list
      try {
        // menuList
        var actionToolbar = this.$refs['actionToolbar'].$el;
        var tbHeight;
        if (actionToolbar) {
          tbHeight = actionToolbar.offsetHeight
        } else {
          tbHeight = 30
        }

        var menuContainer = this.$refs['menuContainer'].$el;
        var addItemContainer = this.$refs['addItemContainer'].$el;
        var itemContainer = this.$refs['itemContainer'].$el;

        itemContainer.style.height = addItemContainer.offsetHeight - 50 + 'px';

        var elmenuList = this.$refs['menuList'].$el;
        if (elmenuList) {
          elmenuList.style.height = menuContainer.offsetHeight - tbHeight - 30 + 'px';
        }

        var traysList = this.$refs['traysList'];
        if (traysList) {
          traysList.style.height = menuContainer.offsetHeight - tbHeight - 30 + 'px';
        }

        // console.log(itemContainer.offsetHeight)
        var commands = this.$refs['commands'];
        // console.log(commands)
        if (commands) {
          commands.style.height = itemContainer.offsetHeight - 55 + 'px';
        }

        var toolbars = this.$refs['toolbars'];
        // console.log(toolbars)
        if (toolbars) {
          toolbars.style.height = itemContainer.offsetHeight - 55 + 'px';
        }

      } catch (error) {
        console.log(error);
      }
    },
    loadIcon(cmd, e){
      // console.log(cmd, e)
      if (cmd.icon_extname == '.svg'){
        this.svgToPng(cmd, e)
      }
    },
    svgToPng(cmd, e){
      if (cmd.icon_extname == '.svg') {
        const svgImage = e.target;
        var canvas = document.getElementById("canvas"),
            context = canvas.getContext("2d");
  
        // canvas.width = svgImage.naturalWidth;
        // canvas.height = svgImage.naturalHeight;
  
        canvas.width = 64;
        canvas.height = 64;
        context.drawImage(svgImage, 0, 0, 64, 64);
  
        const imgData = canvas.toDataURL('image/png');
        // console.log(imgData)
        sketchup.svgToPng(cmd, imgData);
        context.clearRect(0, 0, canvas.width, canvas.height);
      }
    }
  },
  computed: {
    commandsListHeight(){
      return this.windowHeight - 100 + 'px';
    },
    instructionCardStyle(){
      if (this.stepInstruction == 1){
        return {
          'background-color': 'cadetblue',
          color: 'white'
        }
      } else if(this.stepInstruction == 2) {
        return {
          'background-color': 'blue',
          color: 'white'
        }
      } else if(this.stepInstruction == 3) {
        return {
          'background-color': 'brown',
          color: 'white'
        }
      } else if(this.stepInstruction == 4) {
        return {
          'background-color': 'darkolivegreen',
          color: 'white'
        }
      } else {
        return {
          'background-color': 'darkolivegreen',
          color: 'white'
        }
      }
    },
  },
  updated: function () {
    this.$nextTick(function () {
      this.layoutUI();
    })
  },
  mounted: function() {
    this.windowHeight = window.innerHeight;
    this.windowWidth = window.outerWidth;

    setTimeout(() => {
      app.layoutUI();
    }, 300);

    sketchup.ready(window.outerWidth, window.outerHeight);
    sketchup.search(this.search)

    this.$nextTick(() => {
      window.addEventListener("resize", () => {
        // console.log('resizze')

        app.windowHeight = window.innerHeight;
        app.windowWidth = window.outerWidth;
        app.layoutUI();
      });
    });
  },
})

function updateMenus(menus) {
  app.menus = menus;
  app.selectedMenu = menus[0];
  if (app.selectedMenu && app.selectedMenu.trays)
  {
    activeTray = app.selectedMenu.trays.find(t=>{
      return t.active;
    })
    if (activeTray) {
      app.selectedTray = activeTray;
    } else {
      app.selectedTray = app.selectedMenu.trays[0];
    }
  }
}

function setActiveTray(name) {
  try {
    app.selectedTray = app.selectedMenu.trays.find(tray=>{
      return tray.name == name
    })
  } catch (error) {
    app.$alert(error);
  }
}

function setActiveMenu(menu) {
  // console.log('setActiveMenu', menu)

  var menuObj = app.menus.find(m => {
    return m.name == menu;
  })

  if (menuObj && app.selectedMenu != menuObj){
    app.selectedMenu = menuObj;
    
    activeTray = app.selectedMenu.trays.find(t=>{
      return t.active;
    })
    if (activeTray) {
      app.selectedTray = activeTray;
    } else {
      app.selectedTray = app.selectedMenu.trays[0];
    }
  }
}

function getCommandSvgImages(commands) {
  app.svgImageCommands = commands;
}

function clearSVG() {
  app.svgImageCommands = []
}
