// ELEMENT.locale(ELEMENT.lang.en)
// Vue app

var app = new Vue({
  el: '#app',
  data: function() {
    return {
      trays: [],
      commands: [],
      toolbars: [],
      activeTray: '',
      activeTab: 'commands',
      search: 'Curic',
      windowHeight: 500,
      windowWidth: 500,
    }
  },
  watch: {
    focus(newValue, oldValue) {
      console.log("focus" + newValue)
      sketchup.mouseFocusChanged(newValue)
    },

    search(newValue, oldValue) {
      sketchup.search(newValue)
    },
  }, 
  methods: {
    activeTabChange(name){
      console.log('active tab chang', name);
    },  
    mouseOver(){
      this.focus = true
    },
    mouseLeave(){
      this.focus = false
    },
    addCommand(cmd){
      console.log(cmd)
      sketchup.addCommand(cmd);
    },
    addToolbar(toolbar){
      console.log(toolbar)
      sketchup.addToolbar(toolbar);
    },
    newTray(){
      sketchup.newTray();
    },
    removeTray(){
      sketchup.removeTray();
    },
    loadMenu(){
      sketchup.loadMenu();
    },    
    exportMenu(){
      sketchup.exportMenu();
    },
    AddCircleLayout(){
      sketchup.AddLayout('circle');
    },
    AddCircleReactangleLayout(){
      sketchup.AddLayout('rectangle');
    },
    layoutList() {
      // Set height for font list
      try {
        var el;
        if (this.activeTab == 'commands') {
          el = this.$refs['tabCommandList'].$el
        } else {
          el = this.$refs['tabToolbarList'].$el
        }
        
        el.style.height = this.windowHeight - 150 + 'px';
      } catch (error) {
        console.log(error);
      }
    },
  },
  computed: {
    commandsListHeight(){
      return this.windowHeight - 100 + 'px';
    }
  },
  updated: function () {
    this.$nextTick(function () {
      this.layoutList();
    })
  },
  mounted: function() {
    this.windowHeight = window.innerHeight;
    this.windowWidth = window.outerWidth;

    setTimeout(() => {
      app.layoutList();
    }, 300);

    sketchup.ready(window.outerWidth, window.outerHeight);
    sketchup.search(this.search)

    this.$nextTick(() => {
      window.addEventListener("resize", () => {
        console.log('resizze')

        app.windowHeight = window.innerHeight;
        app.windowWidth = window.outerWidth;
        app.layoutList();
      });
    });
  },
})

function updateData(trays) {
  app.trays = trays;
  activeTray = trays.find(tray=>{
    return tray.active;
  })

  if (activeTray){ app.activeTray = activeTray.name }
}